@@ -104,21 +104,31 @@ class Machine():
     def machine_state(self):
         return self._machine_state
 
+
     @machine_state.setter
     def machine_state(self, value):
         self._machine_state = value
         _LOGGER.debug(value)
+    
+    @property
+    def machine_id(self):
+        return self._machine_id
      
  
-    def retrieve_machine_state(self):
+    def retrieve_machine_state(self, update_zones = False):
         state = self._api.retrieve_state(self._machine_id, 0)
         if state is not None and len(state) > 0:
             if self._zones == {}:
-                self.discover_zones(state)            
+                self.discover_zones(state)
             self.machine_state = state[0]
+            if update_zones:
+                for z in state:
+                    zone_id = z['zoneID']
+                    if zone_id in self._zones:
+                        self._zones[zone_id].zone_state = z
     
     def discover_zones(self, state):
-        self._zones = {z['zoneID']: Zone(self._api, self._machine_id, z['zoneID']) for z in state if z['zoneID'] != 0}        
+        self._zones = {z['zoneID']: Zone(self._api, self, z['zoneID']) for z in state if z['zoneID'] != 0}        
                     
     @property
     def zones(self):
@@ -171,9 +181,10 @@ class Machine():
 
 
 class Zone:
-    def __init__(self, api, machine_id, zone_id):  
+    def __init__(self, api, machine, zone_id):  
         self._api = api
-        self._machine_id = machine_id              
+        self._machine = machine
+        self._machine_id = self.machine.machine_id              
         self._zone_id = zone_id        
         self.zone_state = None      
         self._name = f"Zone_{zone_id}"
@@ -191,6 +202,10 @@ class Zone:
     def zone_state(self, value):
         self._zone_state = value
 
+    @property
+    def machine(self):
+        return self._machine
+
     def retrieve_zone_state(self):
         state = self._api.retrieve_state(self._machine_id, self._zone_id)        
         if state is not None and len(state)> 0:
@@ -203,7 +218,7 @@ class Zone:
         self._set_parameter_value('on', 1)
 
     def turn_off(self):
-        self._set_parameter_value('on', 0)
+        self._set_parameter_value('on', 0)    
 
     @property
     def signal_temperature_value(self):
